Author: rinrab
Date: Sat May 31 19:22:49 2025
New Revision: 1926015
URL: http://svn.apache.org/viewvc?rev=1926015&view=rev
Log:
On the 'utf8-cmdline-prototype' branch: Sync with trunk, resolving conflicts.
Modified:
subversion/branches/utf8-cmdline-prototype/ (props changed)
subversion/branches/utf8-cmdline-prototype/configure.ac
subversion/branches/utf8-cmdline-prototype/subversion/include/private/svn_cmdline_private.h
subversion/branches/utf8-cmdline-prototype/subversion/libsvn_subr/cmdline.c
subversion/branches/utf8-cmdline-prototype/subversion/svn/svn.c
subversion/branches/utf8-cmdline-prototype/subversion/svnmucc/svnmucc.c
subversion/branches/utf8-cmdline-prototype/subversion/svnrdump/svnrdump.c
subversion/branches/utf8-cmdline-prototype/subversion/svnsync/svnsync.c
subversion/branches/utf8-cmdline-prototype/tools/client-side/svn-mergeinfo-normalizer/svn-mergeinfo-normalizer.c
Propchange: subversion/branches/utf8-cmdline-prototype/
------------------------------------------------------------------------------
Merged /subversion/trunk:r1925930-1926014
Modified: subversion/branches/utf8-cmdline-prototype/configure.ac
URL: http://svn.apache.org/viewvc/subversion/branches/utf8-cmdline-prototype/configure.ac?rev=1926015&r1=1926014&r2=1926015&view=diff
==============================================================================
--- subversion/branches/utf8-cmdline-prototype/configure.ac (original)
+++ subversion/branches/utf8-cmdline-prototype/configure.ac Sat May 31 19:22:49 2025
@@ -61,7 +61,8 @@ If:
PathExclude: [subversion/bindings/javahl/native/.*]
CompileFlags:
- Add:'
+ Add:
+ - --language=c'
svn_dot_clangdxx_contents='---
# C++
@@ -69,7 +70,8 @@ If:
PathMatch: [.*\.[ch]pp|.*/bindings/javahl/native/.*\.h]
CompileFlags:
- Add:'
+ Add:
+ - --language=c++'
],
[])
Modified: subversion/branches/utf8-cmdline-prototype/subversion/include/private/svn_cmdline_private.h
URL: http://svn.apache.org/viewvc/subversion/branches/utf8-cmdline-prototype/subversion/include/private/svn_cmdline_private.h?rev=1926015&r1=1926014&r2=1926015&view=diff
==============================================================================
--- subversion/branches/utf8-cmdline-prototype/subversion/libsvn_subr/cmdline.c (original)
+++ subversion/branches/utf8-cmdline-prototype/subversion/libsvn_subr/cmdline.c Sat May 31 19:22:49 2025
@@ -1222,21 +1222,29 @@ svn_cmdline__stderr_is_a_terminal(void)
#endif
}
-svn_boolean_t
-svn_cmdline__be_interactive(svn_boolean_t non_interactive,
+svn_error_t *
+svn_cmdline__be_interactive(svn_boolean_t *non_interactive,
svn_boolean_t force_interactive)
{
+ /* The --non-interactive and --force-interactive options are mutually
+ * exclusive. */
+ if (*non_interactive && force_interactive)
+ {
+ return svn_error_create(SVN_ERR_CL_ARG_PARSING_ERROR, NULL,
+ _("--non-interactive and --force-interactive "
+ "are mutually exclusive"));
+ }
+
/* If neither --non-interactive nor --force-interactive was passed,
* be interactive if stdin is a terminal.
* If --force-interactive was passed, always be interactive. */
- if (!force_interactive && !non_interactive)
- {
- return svn_cmdline__stdin_is_a_terminal();
- }
- else if (force_interactive)
- return TRUE;
+ if (!force_interactive && !*non_interactive)
+ *non_interactive = svn_cmdline__stdin_is_a_terminal();
+
+ if (force_interactive)
+ *non_interactive = FALSE;
- return !non_interactive;
+ return SVN_NO_ERROR;
}
Modified: subversion/branches/utf8-cmdline-prototype/subversion/svn/svn.c
URL: http://svn.apache.org/viewvc/subversion/branches/utf8-cmdline-prototype/subversion/svn/svn.c?rev=1926015&r1=1926014&r2=1926015&view=diff
==============================================================================
--- subversion/branches/utf8-cmdline-prototype/subversion/svn/svn.c (original)
+++ subversion/branches/utf8-cmdline-prototype/subversion/svn/svn.c Sat May 31 19:22:49 2025
@@ -2753,18 +2753,8 @@ sub_main(int *exit_code,
}
}
- /* The --non-interactive and --force-interactive options are mutually
- * exclusive. */
- if (opt_state.non_interactive && force_interactive)
- {
- return svn_error_create(SVN_ERR_CL_ARG_PARSING_ERROR, NULL,
- _("--non-interactive and --force-interactive "
- "are mutually exclusive"));
- }
- else
- opt_state.non_interactive = !svn_cmdline__be_interactive(
- opt_state.non_interactive,
- force_interactive);
+ SVN_ERR(svn_cmdline__be_interactive(&opt_state.non_interactive,
+ force_interactive));
/* Turn our hash of changelists into an array of unique ones. */
SVN_ERR(svn_hash_keys(&(opt_state.changelists), changelists, pool));
Modified: subversion/branches/utf8-cmdline-prototype/subversion/svnmucc/svnmucc.c
URL: http://svn.apache.org/viewvc/subversion/branches/utf8-cmdline-prototype/subversion/svnmucc/svnmucc.c?rev=1926015&r1=1926014&r2=1926015&view=diff
==============================================================================
--- subversion/branches/utf8-cmdline-prototype/subversion/svnmucc/svnmucc.c (original)
+++ subversion/branches/utf8-cmdline-prototype/subversion/svnmucc/svnmucc.c Sat May 31 19:22:49 2025
@@ -658,15 +658,7 @@ sub_main(int *exit_code,
return SVN_NO_ERROR;
}
- if (non_interactive && force_interactive)
- {
- return svn_error_create(SVN_ERR_CL_ARG_PARSING_ERROR, NULL,
- _("--non-interactive and --force-interactive "
- "are mutually exclusive"));
- }
- else
- non_interactive = !svn_cmdline__be_interactive(non_interactive,
- force_interactive);
+ SVN_ERR(svn_cmdline__be_interactive(&non_interactive, force_interactive));
if (!non_interactive)
{
Modified: subversion/branches/utf8-cmdline-prototype/subversion/svnrdump/svnrdump.c
URL: http://svn.apache.org/viewvc/subversion/branches/utf8-cmdline-prototype/subversion/svnrdump/svnrdump.c?rev=1926015&r1=1926014&r2=1926015&view=diff
==============================================================================
--- subversion/branches/utf8-cmdline-prototype/subversion/svnrdump/svnrdump.c (original)
+++ subversion/branches/utf8-cmdline-prototype/subversion/svnrdump/svnrdump.c Sat May 31 19:22:49 2025
@@ -1112,8 +1112,7 @@ sub_main(int *exit_code,
SVN_ERR(svn_cmdline__stdin_readline(&password, pool, pool));
}
- non_interactive = !svn_cmdline__be_interactive(non_interactive,
- force_interactive);
+ SVN_ERR(svn_cmdline__be_interactive(&non_interactive, force_interactive));
SVN_ERR(init_client_context(&(opt_baton->ctx),
non_interactive,
Modified: subversion/branches/utf8-cmdline-prototype/subversion/svnsync/svnsync.c
URL: http://svn.apache.org/viewvc/subversion/branches/utf8-cmdline-prototype/subversion/svnsync/svnsync.c?rev=1926015&r1=1926014&r2=1926015&view=diff
==============================================================================
--- subversion/branches/utf8-cmdline-prototype/subversion/svnsync/svnsync.c (original)
+++ subversion/branches/utf8-cmdline-prototype/subversion/svnsync/svnsync.c Sat May 31 19:22:49 2025
@@ -2152,18 +2152,23 @@ sub_main(int *exit_code,
break;
case 'M':
- if (!config_options)
- config_options =
- apr_array_make(pool, 1,
- sizeof(svn_cmdline__config_argument_t*));
-
- SVN_ERR(svn_cmdline__parse_config_option(
- config_options,
- apr_psprintf(pool,
- "config:miscellany:memory-cache-size=%s",
- opt_arg),
- NULL /* won't be used */,
- pool));
+ {
+ svn_cmdline__config_argument_t *new_option =
+ apr_pcalloc(pool, sizeof(*new_option));
+
+ if (!config_options)
+ config_options =
+ apr_array_make(pool, 1,
+ sizeof(svn_cmdline__config_argument_t*));
+
+ new_option->file = SVN_CONFIG_CATEGORY_CONFIG;
+ new_option->section = SVN_CONFIG_SECTION_MISCELLANY;
+ new_option->option = SVN_CONFIG_OPTION_MEMORY_CACHE_SIZE;
+ new_option->value = apr_pstrdup(pool, opt_arg));
+
+ APR_ARRAY_PUSH(config_options,
+ svn_cmdline__config_argument_t *) = new_option;
+ }
break;
case '?':
@@ -2186,18 +2191,8 @@ sub_main(int *exit_code,
if (opt_baton.help)
subcommand = svn_opt_get_canonical_subcommand3(svnsync_cmd_table, "help");
- /* The --non-interactive and --force-interactive options are mutually
- * exclusive. */
- if (opt_baton.non_interactive && force_interactive)
- {
- return svn_error_create(SVN_ERR_CL_ARG_PARSING_ERROR, NULL,
- _("--non-interactive and --force-interactive "
- "are mutually exclusive"));
- }
- else
- opt_baton.non_interactive = !svn_cmdline__be_interactive(
- opt_baton.non_interactive,
- force_interactive);
+ SVN_ERR(svn_cmdline__be_interactive(&opt_baton.non_interactive,
+ force_interactive));
/* Disallow the mixing --username/password with their --source- and
--sync- variants. Treat "--username FOO" as "--source-username
Modified: subversion/branches/utf8-cmdline-prototype/tools/client-side/svn-mergeinfo-normalizer/svn-mergeinfo-normalizer.c
URL: http://svn.apache.org/viewvc/subversion/branches/utf8-cmdline-prototype/tools/client-side/svn-mergeinfo-normalizer/svn-mergeinfo-normalizer.c?rev=1926015&r1=1926014&r2=1926015&view=diff
==============================================================================
--- subversion/branches/utf8-cmdline-prototype/tools/client-side/svn-mergeinfo-normalizer/svn-mergeinfo-normalizer.c (original)
+++ subversion/branches/utf8-cmdline-prototype/tools/client-side/svn-mergeinfo-normalizer/svn-mergeinfo-normalizer.c Sat May 31 19:22:49 2025
@@ -607,18 +607,8 @@ sub_main(int *exit_code,
}
}
- /* The --non-interactive and --force-interactive options are mutually
- * exclusive. */
- if (opt_state.non_interactive && force_interactive)
- {
- return svn_error_create(SVN_ERR_CL_ARG_PARSING_ERROR, NULL,
- _("--non-interactive and --force-interactive "
- "are mutually exclusive"));
- }
- else
- opt_state.non_interactive = !svn_cmdline__be_interactive(
- opt_state.non_interactive,
- force_interactive);
+ SVN_ERR(svn_cmdline__be_interactive(&opt_state.non_interactive,
+ force_interactive));
/* --password-from-stdin can only be used with --non-interactive */
if (read_pass_from_stdin && !opt_state.non_interactive)
lmpx.com only provides a reader for public news (NNTP) servers. It is not
affiliated with the servers or forums shown here and is not responsible for
the content of articles, which is written by their respective authors.
--- subversion/branches/utf8-cmdline-prototype/subversion/include/private/svn_cmdline_private.h (original)
+++ subversion/branches/utf8-cmdline-prototype/subversion/include/private/svn_cmdline_private.h Sat May 31 19:22:49 2025
@@ -226,15 +226,18 @@ svn_cmdline__stdout_is_a_terminal(void);
svn_boolean_t
svn_cmdline__stderr_is_a_terminal(void);
/* Determine whether interactive mode should be enabled, based on whether
* the user passed the --non-interactive or --force-interactive options.
* If neither option was passed, interactivity is enabled if standard
* input is connected to a terminal device.
*
* @since New in 1.8.
*/
-svn_boolean_t
-svn_cmdline__be_interactive(svn_boolean_t non_interactive,
+svn_error_t *
+svn_cmdline__be_interactive(svn_boolean_t *non_interactive,
svn_boolean_t force_interactive);
/* Parses the argument value of '--trust-server-cert-failures' OPT_ARG into
Modified: subversion/branches/utf8-cmdline-prototype/subversion/libsvn_subr/cmdline.c
@@ -226,15 +226,18 @@ svn_cmdline__stdout_is_a_terminal(void);
svn_boolean_t
svn_cmdline__stderr_is_a_terminal(void);
-/* Determine whether interactive mode should be enabled, based on whether
- * the user passed the --non-interactive or --force-interactive options.
- * If neither option was passed, interactivity is enabled if standard
- * input is connected to a terminal device.
+/* Adjusts boolean described by @a non_interactive to whether interactive
+ * mode should be disabled, based on whether the user passed the
+ * --non-interactive or --force-interactive options. If neither option
+ * was passed, interactivity is enabled if standard input is connected to a terminal device.
+ *
+ * If both, @a non_interactive and @a force_interactive are @c TRUE, an
+ * @c SVN_ERR_CL_ARG_PARSING_ERROR error will be returned.
*
* @since New in 1.8.
URL: http://svn.apache.org/viewvc/subversion/branches/utf8-cmdline-prototype/subversion/libsvn_subr/cmdline.c?rev=1926015&r1=1926014&r2=1926015&view=diff
==============================================================================